@@ -1,3 +1,4 @@
+from django.core.cache.backends.redis import RedisCache as DjangoRedisCache
 from django_redis import cache, exceptions
 
 from django_prometheus.cache.metrics import (
@@ -20,13 +21,27 @@ class RedisCache(cache.RedisCache):
             django_cache_get_fail_total.labels(backend="redis").inc()
             if self._ignore_exceptions:
                 if self._log_ignored_exceptions:
-                    cache.logger.error(str(e))
+                    self.logger.error(str(e))
                 return default
             raise
         else:
             if cached is not None:
                 django_cache_hits_total.labels(backend="redis").inc()
                 return cached
-            else:
-                django_cache_misses_total.labels(backend="redis").inc()
-                return default
+            django_cache_misses_total.labels(backend="redis").inc()
+            return default
+
+
+class NativeRedisCache(DjangoRedisCache):
+    def get(self, key, default=None, version=None):
+        django_cache_get_total.labels(backend="native_redis").inc()
+        try:
+            result = super().get(key, default=None, version=version)
+        except Exception:
+            django_cache_get_fail_total.labels(backend="native_redis").inc()
+            raise
+        if result is not None:
+            django_cache_hits_total.labels(backend="native_redis").inc()
+            return result
+        django_cache_misses_total.labels(backend="native_redis").inc()
+        return default
