@@ -4,7 +4,14 @@ from redis import RedisError
 
 from django_prometheus.testutils import assert_metric_equal, get_metric
 
-_SUPPORTED_CACHES = ["memcached.PyLibMCCache", "memcached.PyMemcacheCache", "filebased", "locmem", "redis"]
+_SUPPORTED_CACHES = [
+    "memcached.PyLibMCCache",
+    "memcached.PyMemcacheCache",
+    "filebased",
+    "locmem",
+    "native_redis",
+    "redis",
+]
 
 
 class TestCachesMetrics:
@@ -63,5 +70,5 @@ class TestCachesMetrics:
         tested_cache = caches[supported_cache]
         tested_cache.set("foo1", "bar v.1", version=1)
         tested_cache.set("foo1", "bar v.2", version=2)
-        assert "bar v.1" == tested_cache.get("foo1", version=1)
-        assert "bar v.2" == tested_cache.get("foo1", version=2)
+        assert tested_cache.get("foo1", version=1) == "bar v.1"
+        assert tested_cache.get("foo1", version=2) == "bar v.2"
