@@ -12,10 +12,10 @@ def M(metric_name):
     This is just intended to help keep the lines shorter in test
     cases.
     """
-    return "django_migrations_%s" % metric_name
+    return f"django_migrations_{metric_name}"
 
 
-@pytest.mark.django_db()
+@pytest.mark.django_db
 class TestMigrations:
     """Test migration counters."""
 
