@@ -1,5 +1,4 @@
-"""
-WSGI config for testapp project.
+"""WSGI config for testapp project.
 
 It exposes the WSGI callable as a module-level variable named ``application``.
 
